<?php
if ( !defined( 'ABSPATH' ) ) {
    wp_die();
}
if ( !class_exists( 'WPF_Product_Option_Common' ) ) {
 	class WPF_Product_Option_Common {
 		public function __construct() {
 			add_action( 'init', array(__CLASS__, 'wpf_product_options_rules' ) );
 			add_action( 'rest_api_init', array(__CLASS__, 'wpf_create_api_posts_meta_field') );
            add_action( 'wp_ajax_wpf_variation_options', array(__CLASS__, 'wpf_variation_options') );
            add_action( 'wp_ajax_nopriv_wpf_variation_options', array(__CLASS__, 'wpf_variation_options') );
 		}
         public static function wpf_variation_options() {
             check_ajax_referer('wpf_ajax_nonce', 'nonce');
             if ( empty($_POST['product_id']) ) {
                wp_send_json_error();
             }
             $product_id = wc_clean($_POST['product_id']);
             $status = get_post_meta($product_id, 'wpf_enable_product_options', true);
            if ( empty($status) || 'no' == $status ) {
                wp_send_json_error();
            }
            $rule_id = get_post_meta($product_id, 'wpf_select_option', true);
            if ( empty($rule_id) ) {
                wp_send_json_error();
            }
            $product = wc_get_product($product_id);
            $html = wpf_options_html( $rule_id, $product );
            wp_send_json_success($html);
         }
 		public static function wpf_product_options_rules() {
            $labels = array(
                'name'               => esc_html_x( 'Product Options Ruleset', 'Custom post type name', 'wc-wpf'),
                'singular_name'      => esc_html_x( 'Product Options Ruleset', 'Custom post type name', 'wc-wpf'),
				'add_new_item'       => esc_html__( 'Add New Rule', 'wc-wpf'),
				'new_item'           => esc_html__( 'New Rule', 'wc-wpf'),
                'view_item'          => esc_html__( 'View Rule', 'wc-wpf'),
                'all_items'          => esc_html__( 'All Rule', 'wc-wpf'),
                'search_item'        => esc_html__( 'Search Rule', 'wc-wpf'),
                'edit_item'          => esc_html__( 'Edit Rule', 'wc-wpf'),
                'update_item'        => esc_html__( 'Update Rule', 'wc-wpf'),
                'not_found'          => esc_html__( 'Rule Not Found', 'wc-wpf'),
                'not_found_in_trash' => esc_html__( 'Rule not Found in Trash', 'wc-wpf' )
            );
            $args = array(
                'labels'             => $labels,
                'description'        => esc_html__( 'Description.', 'wc-wpf' ),
                'public'             => true,
                'publicly_queryable' => false,
                'show_ui'            => true,
                'show_in_menu'       => 'wpf-product-options',
				'show_in_rest' 		 => true,
                'query_var'          => true,
                'map_meta_cap'       => true,
				'rest_controller_class' => 'WP_REST_Posts_Controller',
                'has_archive'        => true,
                'hierarchical'       => false,
                'menu_position'      => null,
                'supports'           => array('title'),
            );
            register_post_type( 'wpf_product_options', $args);
        }
        public static function wpf_create_api_posts_meta_field() {
            register_rest_field( 'wpf_product_options', 'meta', array(
                    'get_callback' => array(__CLASS__, 'wcf_get_post_meta_for_api'),
                    'schema'       => null,
                )
            );
        }
        public static function wcf_get_post_meta_for_api( $object ) {
            $post_id = $object['id'];
            return get_post_meta( $post_id );
        }
 	}
 	new WPF_Product_Option_Common();
}