<?php 
if ( !defined( 'ABSPATH' ) ) {
	wp_die();
}
if ( !function_exists('wpf_options_html') ) {
    function wpf_options_html( $rule_id, $product ) {
        ob_start();
        $options = get_post_meta($rule_id, 'wpf_product_option_rulset', true);
        if ( !empty($options) ) {
            echo '<div class="wpf_prduct_addons" data-product_price="' . esc_attr($product->get_price()) . '">';
            foreach ( $options as $key => $option ) {
                switch( $option['wpf_rule_type'] ) {
                    case 'radio':
                        if ( !empty($option['wpf_multi_options_label']) ) {
                            wpf_radio_html($option, $key);
                        }
                    break;
                    case 'dropdown':
                        if ( !empty($option['wpf_multi_options_label']) ) {
                            wpf_dropdown_html($option, $key);
                        }
                    break;
                    case 'checkboxes':
                        if ( !empty($option['wpf_multi_options_label']) ) {
                            wpf_checkbox_html($option, $key);
                        }
                    break;
                    case 'images':
                        if ( !empty($option['wpf_multi_options_image']) ) {
                            wpf_images_html($option, $key);
                        }
                    break;
                    case 'text_field':
                        wpf_text_field_html($option, $key);
                    break;
                    case 'text_area':
                        wpf_textarea_html($option, $key);
                    break;
                    case 'price':
                        wpf_price_html($option, $key);
                    break;
                    case 'quantity':
                        wpf_quantity_html($option, $key);
                    break;
                    case 'file':
                        wpf_upload_file_html($option, $key);
                    break;
                    case 'date':
                        wpf_date_html($option, $key);
                    break;
                    case 'time':
                        wpf_time_html($option, $key);
                    break;
                    case 'colorpicker':
                        wpf_colorpicker_html($option, $key);
                    break;
                    case 'multiselect':
                        wpf_multiselect_html($option, $key);
                    break;
                    case 'heading':
                        wpf_heading_html($option, $key);
                    break;
                    case 'range_picker':
                        wpf_range_picker_html($option, $key);
                    break;
                    case 'date_range_picker':
                        wpf_date_range_picker_html($option, $key);
                    break;
					case 'composite_products':
						wpf_composite_products_html($option, $key);
						break;
					case 'shortcode-html':
                        wpf_shortcode_html($option, $key);
                    break;
                }
            }
            if ( empty(get_option('wpf_hide_summary_table')) ) {
                wpf_options_summary();
            }
            $options = wp_json_encode($options);
            echo '<input type="hidden" name="wpf_options_array" class="wpf_options_array" value="' . wc_esc_json($options) . '" /></div>';
        }
        return ob_get_clean();
    }
}
if ( !function_exists('wpf_composite_products_html') ) {
	function wpf_composite_products_html( $option, $key ) {
			$required = ( 'yes' == $option['wpf_option_required'] ) ? 'required' : '';
			$cols = 'wpf-col-4';
			$multi_allow = $option['wpf_option_allow_multiple']; 
			$product_ids = $option['wpf_option_products']; 
			
		
		echo '<div class="wpf_options wpf_option_' . esc_attr($key) .'">';
			wpf_common_options( $option, '' ); 
			echo '<div class="wpf_toggle">';
		
			$product_ids = array_filter($product_ids);
			if ( empty($product_ids) ) {
				return;
			}
			?>
			<div class="wpf-row wpf_product wpf_product_<?php echo esc_attr($key); ?>">
				<?php if ( 'yes' != $option['wpf_option_required'] && 'yes' != $multi_allow ) { ?>
					<span class="<?php echo esc_attr($cols); ?> wpf_product_thumbnail " data-label="<?php esc_attr_e('None', 'wc-wpf'); ?>" data-multi_allow="<?php echo esc_attr($multi_allow); ?>"><label>
							<img src="<?php echo esc_url( WP_WPF_URL . 'assets/no-img.png' ); ?>" />
							<input type="radio" name="wpf_product_<?php echo esc_attr($key); ?>" data-price="0" value="" />
							<p><?php esc_html_e('None', 'wc-wpf'); ?></p>
						</label>
					</span>
					<?php 
				}
				foreach ( $product_ids as $i => $product_id ) {
					$option_status = get_post_meta($product_id, 'wpf_enable_product_options', true);
					$rule_id = get_post_meta($product_id, 'wpf_select_option', true);
					if ( $product_id == get_the_ID() ) {
						continue;
					}
					if ( !empty($option_status) && !empty($rule_id) ) {
						continue;
					}
					$product = wc_get_product($product_id);
					echo '<span class="wpf-col-4' . ' wpf_product_thumbnail wpf_products_' . esc_attr($key) . '" data-label="' . esc_attr($product->get_name()) . '" data-price="' . esc_attr($product->get_price()) . '" data-multi_allow="' . esc_attr($multi_allow) . '"><label>';
					echo $product->get_image();
					if ( 'yes' == $multi_allow  ) {
						echo '<input type="checkbox" name="wpf_product_' . esc_attr($key) . '[]" value="' . esc_attr($product_id) . '" data-price="' . esc_attr($product->get_price()) . '" data-label="' . esc_attr($product->get_name()) . '" ' . esc_attr($required) . ' />';
					} else {
						echo '<input type="radio" name="wpf_product_' . esc_attr($key) . '[]" value="' . esc_attr($product_id) . '" data-price="' . esc_attr($product->get_price()) . '" data-label="' . esc_attr($product->get_name()) . '" ' . esc_attr($required) . ' />';
					}
					if ( 'yes' != get_option('wpf_hide_images_title') ) {
						?>
						<p class="wpf_product_label"><?php
							
								esc_html_e( $product->get_name(), 'wc-wpf');
// 			if ( ('required' == $required || 'yes' == $required) ) {
// 				echo '<span class="required">*</span>';
// 			}
			echo '<span class="wpf_price_label"> ' . wp_kses_post($product->get_price_html()) . '</span>';
							?></p>
						<?php
					}
					echo '</label></span>';
				} 
				?>
			</div>
			<?php 
		if ( !empty($option['wpf_option_desc']) ) {
				echo '<p class="wpf_description">' . esc_html__($option['wpf_option_desc'], 'wc-wpf') . '</p>';
			}
			echo '</div></div>';
		}
}
if ( !function_exists('wpf_get_element_label') ) {
    function wpf_get_element_label( $label, $price, $is_required = '' ) {
        if ( empty(get_option('wpf_hide_addons_price')) ) {
            $element_label = sprintf(' %s %s %s', esc_html__($label, 'wc-wpf'), $is_required, $price);
        } else {
            $element_label = sprintf(' %s %s', esc_html__($label, 'wc-wpf'), $is_required);
        }
        return $element_label;
    }
}
if ( !function_exists('wpf_radio_html') ) {
    function wpf_radio_html( $option, $key ) {
        $option_labels = $option['wpf_multi_options_label'];
        $option_price_types = $option['wpf_multi_options_price_type'];
        $option_prices = $option['wpf_multi_options_price'];
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : ''; ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options($option, ''); ?>
            <div class="wpf_radio wpf_radio_<?php echo esc_attr($key); ?>">
            <?php if ( 'required' != $required ) { ?>
                <label><input type="radio" name="wpf_radio_<?php echo esc_attr($key) ?>" class="wpf_radio_buttons" /><?php esc_html_e(' None', 'wc-wpf'); ?></label>
            <?php } foreach ( $option_labels as $i => $label ) {
                $type = !empty($option_price_types[$i]) ? $option_price_types[$i] : '';
                    $price1 = !empty($option_prices[$i]) ? $option_prices[$i] : 0;
                    $price = wpf_get_price($type, $price1);
                    if ( 0 == $price1 ) {
                        $price = '';
                    }
                    $element_label = wpf_get_element_label($label, $price);
                    ?>
                    <label><input type="radio" name="wpf_radio_<?php echo esc_attr($key) ?>" <?php echo esc_attr($required); ?> class="wpf_radio_buttons" value="<?php echo esc_attr($i); ?>" data-price="<?php echo esc_attr($price1); ?>" data-type="<?php echo esc_attr($type); ?>" data-label="<?php esc_attr_e($label, 'wc-wpf'); ?>" /><?php echo $element_label; ?></label>
                <?php } ?>
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_dropdown_html') ) {
    function wpf_dropdown_html( $option, $key ) {
        $option_labels = $option['wpf_multi_options_label'];
        $option_price_types = $option['wpf_multi_options_price_type'];
        $option_prices = $option['wpf_multi_options_price'];
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : ''; ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options($option, ''); ?>
            <div class="wpf_dropdown">
                <select class="wpf_dropdown wpf_dropdown_<?php echo esc_attr($key); ?>" name="wpf_dropdown_<?php echo esc_attr($key) ?>" <?php echo esc_attr($required); ?>>
                <?php $label = get_option('wpf_dropdown_select_label');
                $label = !empty($label) ? esc_html__($label, 'wc-wpf') : esc_html__('Select any option', 'wc-wpf') ?>
                    <option value=""><?php esc_html_e($label); ?></option>
                <?php foreach ( $option_labels as $i => $label ) {
                    $type = !empty($option_price_types[$i]) ? $option_price_types[$i] : '';
                    $price1 = !empty($option_prices[$i]) ? $option_prices[$i] : 0;
                    $price = wpf_get_price($type, $price1);
                    if ( 0 == $price1 ) {
                        $price = '';
                    }
                    $element_label = wpf_get_element_label($label, $price);
                    ?>
                        <option value="<?php echo esc_attr($i); ?>" data-price="<?php echo esc_attr($price1); ?>" data-type="<?php echo esc_attr($type); ?>" data-label="<?php esc_attr_e($label, 'wc-wpf'); ?>"><?php echo $element_label; ?></option>
                <?php } ?>
                </select>
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_checkbox_html') ) {
    function wpf_checkbox_html( $option, $key ) {
        $option_labels = $option['wpf_multi_options_label'];
        $option_price_types = $option['wpf_multi_options_price_type'];
        $option_prices = $option['wpf_multi_options_price'];
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : ''; ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options($option, ''); ?>
            <div class="wpf_checkbox wpf_checkbox_<?php echo esc_attr($key) . ' ' . esc_attr($required); ?>">
                <?php foreach ( $option_labels as $i => $label ) {
                    $type = !empty($option_price_types[$i]) ? $option_price_types[$i] : '';
                    $price1 = !empty($option_prices[$i]) ? $option_prices[$i] : 0;
                    $price = wpf_get_price($type, $price1);
                    ?>
                    <label><input type="checkbox" class="wpf_checkbox_buttons" name="wpf_checkboxes_<?php echo esc_attr($key) ?>[]" data-type="<?php echo esc_attr($type); ?>" data-price="<?php echo esc_attr($price1); ?>" data-label="<?php esc_attr_e($label, 'wc-wpf'); ?>" value="<?php echo esc_attr($i); ?>" />
                    <?php
                    if ( 0 == $price1 ) {
                        $price = '';
                    }
                    $element_label = wpf_get_element_label($label, $price);
                    echo $element_label; ?></label>
                <?php } ?>
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_images_html') ) {
    function wpf_images_html( $option, $key ) {
        $option_labels = $option['wpf_multi_options_label'];
        $option_price_types = $option['wpf_multi_options_price_type'];
        $option_prices = $option['wpf_multi_options_price'];
        $option_images = $option['wpf_multi_options_image'];
        $option_images = array_filter($option_images);
        if ( empty($option_images) ) {
            return;
        }
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : '';
        $multi_allow = $option['wpf_option_allow_multiple']; ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options($option, ''); ?>
            <div class="wpf_image wpf-row wpf_image_<?php echo esc_attr($key); ?>">
                    <?php if ( 'yes' != $option['wpf_option_required'] && $multi_allow != 'yes' ) { ?>
                    <div class="wpf-col-4">
                        <label>
                        <div class="wpf_thumbnail wpf-inner" data-label="<?php esc_attr_e('None', 'wc-wpf'); ?>" data-multi_allow="<?php echo esc_attr($multi_allow); ?>">
                        <img src="<?php echo WP_WPF_URL ?>/assets/no-img.png" />
                        <input type="radio" name="wpf_images_<?php echo esc_attr($key); ?>" data-type="" value="" />
                        </div>
                        </label>
                    </div>
                    <?php } ?>
                <?php
                foreach ( $option_images as $i => $image_id ) {
                    $price1 = !empty($option_prices[$i]) ? $option_prices[$i] : 0;
                    $type = !empty($option_price_types[$i]) ? $option_price_types[$i] : '';
                    $price = wpf_get_price($type, $price1);
                    if ( 0 == $price1 ) {
                        $price = '';
                    }
					if ( empty($option_labels[$i]) ) {
						continue;
					}
                    $element_label = wpf_get_element_label($option_labels[$i], $price);
                    echo '<div class="wpf-col-4">
                    <label>
                    <div class="wpf_thumbnail wpf-inner" title="' . $element_label . '" data-label="'.esc_attr($option_labels[$i]).'" data-price="'.esc_attr($price1).'" data-multi_allow="' . esc_attr($multi_allow) . '">';
                        echo wp_get_attachment_image($image_id);
                        if ( $multi_allow == 'yes' ) {
                            echo '<input type="checkbox" name="wpf_images_' . esc_attr($key) . '[]" data-type="' . esc_attr($type) . '" value="' . esc_attr($i) . '" data-price="' . esc_attr($price1) . '" data-label="'.esc_attr__($option_labels[$i], 'wc-wpf').'" data-type="' . esc_attr($option_price_types[$i]) . '" />';
                        } else {
                            echo '<input type="radio" name="wpf_images_' . esc_attr($key) . '" data-type="' . esc_attr($type) . '" value="' . esc_attr($i) . '" data-price="' . esc_attr($price1) . '" data-label="'.esc_attr__($option_labels[$i], 'wc-wpf').'" data-type="' . esc_attr($option_price_types[$i]) . '" />';
                        }
                    echo '</div></label>';
					if ( 'yes' != get_option('wpf_hide_images_title') ) {
                            echo '<p class="wpf_image_label">' . esc_html($element_label) . '</p>';
                        }
					echo '</div>';
                } ?>
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_text_field_html') ) {
    function wpf_text_field_html( $option, $key ) {
        $price = $option['wpf_options_price'];
        $price = !empty($price) ? $price : 0;
        $pricing_type = $option['wpf_option_pricing_type'];
        $limit = $option['wpf_options_limit'];
        $field_type = $option['wpf_text_field_restriction'];
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : '';
        $price = wpf_get_price($pricing_type, $price);
        $type = 'text';
        $pattern = '';
        if ( 'any_text' == $field_type ) {
            $type = 'text';
        } else if ( 'only_letter' == $field_type ) {
            $type = 'text';
            $pattern = 'pattern[A-Za-z]+';
        } else if ( 'only_number' == $field_type ) {
            $type = 'number';
        } else if ( 'letter_number' == $field_type ) {
            $type = 'text';
            $pattern = 'pattern[A-Za-z0-9]+';
        } else if ( 'only_email' == $field_type ) {
            $type = 'email';
        } ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options( $option, $price ); ?>
            <div class="wpf_textfield wpf_text_field_<?php echo esc_attr($key); ?>">
                <input type="<?php echo esc_attr($type); ?>" class="wpf_text_field" name="wpf_text_field_<?php echo esc_attr($key); ?>" <?php echo esc_attr($required); ?> maxLength="<?php echo esc_attr($limit); ?>" <?php echo esc_attr($pattern); ?> />
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_textarea_html') ) {
    function wpf_textarea_html( $option, $key ) {
        $price = $option['wpf_options_price'];
        $price = !empty($price) ? $price : 0;
        $pricing_type = $option['wpf_option_pricing_type'];
        $limit = $option['wpf_options_limit'];
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : '';
        $price = wpf_get_price( $pricing_type, $price ); ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options( $option, $price ); ?>
            <div class="wpf_textarea wpf_textarea_<?php echo esc_attr($key); ?>">
                <textarea class="wpf_textarea" name="wpf_text_area_<?php echo esc_attr($key); ?>" maxLength="<?php echo esc_attr($limit);?>" <?php echo esc_attr($required); ?>></textarea>
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_quantity_html') ) {
    function wpf_quantity_html( $option, $key ) { 
        $price1 = $option['wpf_options_price'];
        $price = !empty($price1) ? $price1 : 0;
        $min_qty = $option['wpf_options_min_qty'];
		$step = $option['wpf_options_step'];
        $max_qty = $option['wpf_options_max_qty'];
        $pricing_type = $option['wpf_option_pricing_type'];
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : '';
        $price = wpf_get_price($pricing_type, $price); ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options($option, $price); ?>
            <div class="wpf_quantity wpf_quantity_<?php echo esc_attr($key); ?>">
                <input type="number" step="any" class="wpf_quatity_field" name="wpf_quantity_<?php echo esc_attr($key); ?>" min="<?php echo esc_attr($min_qty); ?>" step="<?php echo esc_attr($step); ?>" max="<?php echo esc_attr($max_qty); ?>" value="" <?php echo esc_attr($required); ?> />
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_heading_html') ) {
    function wpf_heading_html( $option, $key ) { ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options( $option, '' ); ?>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_price_html') ) {
    function wpf_price_html( $option, $key ) {
        $min_price = $option['wpf_options_min_price'];
        $max_price = $option['wpf_options_max_price'];
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : ''; ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options( $option, '' ); ?>
            <div class="wpf_price wpf_price_<?php echo esc_attr($key); ?>">
                <input type="number" step="any" class="wpf_price_field" name="wpf_price_<?php echo esc_attr($key) ?>" min="<?php echo esc_attr($min_price); ?>" max="<?php echo esc_attr($max_price); ?>" <?php echo esc_attr($required); ?> />
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_upload_file_html') ) {
    function wpf_upload_file_html( $option, $key ) {
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : '';
        $price1 = $option['wpf_options_price'];
        $price = !empty($price1) ? $price1 : 0;
        $pricing_type = $option['wpf_option_pricing_type'];
        $price = wpf_get_price($pricing_type, $price); ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options( $option, $price ); ?>
            <div class="wpf_file wpf_file_<?php echo esc_attr($key); ?>">
                <input type="file" class="wpf_upload_file" name="wpf_file_<?php echo esc_attr($key) ?>" <?php echo esc_attr($required); ?> />
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_date_html') ) {
    function wpf_date_html( $option, $key ) {
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : '';
        $pricing_type = $option['wpf_option_pricing_type'];
        $price1 = $option['wpf_options_price'];
        $price = !empty($price1) ? $price1 : 0;
        $price = wpf_get_price($pricing_type, $price); ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options( $option, $price ); ?>
            <div class="wpf_date wpf_date_<?php echo esc_attr($key); ?>">
                <input type="date" class="wpf_date" name="wpf_date_<?php echo esc_attr($key) ?>" <?php echo esc_attr($required); ?> />
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_time_html') ) {
    function wpf_time_html( $option, $key ) {
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : '';
        $pricing_type = $option['wpf_option_pricing_type'];
        $price1 = $option['wpf_options_price'];
        $price = !empty($price1) ? $price1 : 0;
        $price = wpf_get_price($pricing_type, $price); ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options( $option, $price ); ?>
            <div class="wpf_time wpf_time_<?php echo esc_attr($key); ?>">
                <input type="time" class="wpf_time" name="wpf_time_<?php echo esc_attr($key) ?>" <?php echo esc_attr($required); ?> />
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_shortcode_html') ) {
    function wpf_shortcode_html( $option, $key ) {
        $shortcode = $option['wpf_cutom_html']; ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <div class="wpf_date_range wpf_shortcode_html_<?php echo esc_attr($key); ?>">
              <?php echo do_shortcode($shortcode); ?>
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_colorpicker_html') ) {
    function wpf_colorpicker_html( $option, $key ) {
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : '';
        $pricing_type = $option['wpf_option_pricing_type'];
        $price1 = $option['wpf_options_price'];
        $price = !empty($price1) ? $price1 : 0;
        $price = wpf_get_price($pricing_type, $price); ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options( $option, $price ); ?>
            <div class="wpf_colorpicker wpf_colorpicker_<?php echo esc_attr($key); ?>">
                <input type="color" class="wpf_colorpicker" name="wpf_colorpicker_<?php echo esc_attr($key) ?>" <?php echo esc_attr($required); ?> />
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_multiselect_html') ) {
    function wpf_multiselect_html( $option, $key ) {
        $option_labels = $option['wpf_multi_options_label'];
        $type = !empty($option['wpf_rule_type']) ? $option['wpf_rule_type'] : '';
        $option_price_types = $option['wpf_multi_options_price_type'];
        $option_prices = $option['wpf_multi_options_price'];
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : ''; ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options($option, ''); ?>
            <div class="wpf_multiselect wpf_multiselect_<?php echo esc_attr($key); ?>">
                <select class="wpf_multiselect" name="wpf_multiselect_<?php echo esc_attr($key) ?>[]" data-type="<?php echo esc_attr($type); ?>" <?php echo esc_attr($required); ?> multiple>
                <?php
                foreach ( $option_labels as $i => $label ) {
                    $price1 = !empty($option_prices[$i]) ? $option_prices[$i] : 0;
                    $price = wpf_get_price($option_price_types[$i], $price1);
                    if ( 0 == $price1 ) {
                        $price = '';
                    }
                    $element_label = wpf_get_element_label($label, $price);
                    ?>
                    <option value="<?php echo esc_attr($i); ?>" data-type="<?php echo esc_attr($option_price_types[$i]); ?>" data-price="<?php echo esc_attr($price1); ?>" data-label="<?php esc_attr_e($label, 'wc-wpf'); ?>"><?php echo $element_label; ?></option>
                <?php } ?>
                </select>
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_range_picker_html') ) {
    function wpf_range_picker_html( $option, $key ) { 
        $price1 = $option['wpf_options_price'];
        $price = !empty($price1) ? $price1 : 0;
        $min_qty = $option['wpf_options_min_qty'];
		$step = $option['wpf_options_step'];
        $max_qty = $option['wpf_options_max_qty'];
        $pricing_type = $option['wpf_option_pricing_type'];
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : '';
        $price = wpf_get_price($pricing_type, $price); ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options($option, $price); ?>
            <div class="wpf_range wpf_range_<?php echo esc_attr($key); ?>">
                <input type="range" class="wpf_range_field" name="wpf_range_picker_<?php echo esc_attr($key); ?>" min="<?php echo esc_attr($min_qty); ?>" step="<?php echo esc_attr($step); ?>" max="<?php echo esc_attr($max_qty); ?>" value="" <?php echo esc_attr($required); ?> />
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_date_range_picker_html') ) {
    function wpf_date_range_picker_html( $option, $key ) {
        $required = ($option['wpf_option_required'] == 'yes') ? 'required' : '';
        $pricing_type = $option['wpf_option_pricing_type'];
        $price1 = $option['wpf_options_price'];
        $price = !empty($price1) ? $price1 : 0;
        $price = wpf_get_price($pricing_type, $price); ?>
        <div class="wpf_options wpf_option_<?php echo esc_attr($key); ?>">
            <?php wpf_common_options( $option, $price ); ?>
            <div class="wpf_date_range wpf_date_range_<?php echo esc_attr($key); ?>">
                <input type="text" class="wpf_date_range" name="wpf_date_range_picker_<?php echo esc_attr($key) ?>" <?php echo esc_attr($required); ?> />
            </div>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_title_format') ) {
    function wpf_title_format( $format, $title ) {
        if ( $format == 'label' ) {
            $title = '<label>' . wp_kses_post($title) . '</label>';
        } else if ( 'disable' == $format ) {
            $title = '';
        } else {
            $title = '<h3>' . wp_kses_post($title) . '</h3>';
        }
        return $title;
    }
}
if ( !function_exists('wpf_common_options') ) {
    function wpf_common_options( $option, $price ) {
        $label = !empty($option['wpf_option_label']) ? esc_html__($option['wpf_option_label'], 'wc-wpf') : '';
        $label_format = !empty($option['wpf_label_format']) ? $option['wpf_label_format'] : '';
        $required = !empty($option['wpf_option_required']) ? $option['wpf_option_required'] : '';
        $is_required = '';
        if ( 'heading' != $option['wpf_rule_type'] ) {
            $is_required = ($required == 'yes') ? '<span class="required">*</span>' : '';
        }
        $description = !empty($option['wpf_option_desc']) ? $option['wpf_option_desc'] : '';
        if ( $price == get_woocommerce_currency_symbol() . 0 ) {
            $price = '';
        }
        $show_label = wpf_get_element_label($label, $price, $is_required);
        $show_label = wpf_title_format($label_format, $show_label); ?>
        <div class="wpf_label" data-is_required="<?php echo esc_attr($required); ?>" data-field_label="<?php echo esc_attr($label); ?>">
                <?php echo $show_label; ?>
        </div>
        <div class="wpf_description">
            <p><?php esc_html_e($description); ?></p>
        </div>
        <?php
    }
}
if ( !function_exists('wpf_options_summary') ) {
    function wpf_options_summary() { ?>
        <div class="wpf_options_summary">
            <table>
            </table>
        </div>
    <?php
    }
}
if ( !function_exists('wpf_get_price') ) {
    function wpf_get_price( $option_price_types, $price ) {
        if ( 'percentage' == $option_price_types ) {
            $price = $price . '%';
        } else {
            $price = get_woocommerce_currency_symbol() . $price;
        }
        return $price;
    }
}