<?php
if ( !defined( 'ABSPATH' ) ) {
    wp_die();
}
if ( !class_exists( 'WPF_Product_Option_Rules' ) ) {
 	class WPF_Product_Option_Rules {
 		public function __construct() {
            add_action( 'add_meta_boxes', array(__CLASS__, 'wpf_rules_meta_box') );
            add_action( 'save_post_wpf_product_options', array(__CLASS__, 'wpf_save_rules' ) );
        }
        public static function wpf_rules_meta_box() {
            add_meta_box( 'wpf_product_options_key', esc_html__( 'Product Options', 'wc-wpf' ), array(__CLASS__, 'wpf_rule_fields_data' ), 'wpf_product_options', 'normal' );
			add_meta_box( 'wpf_products_key', esc_html__( 'Search Products', 'wc-wpf' ), array(__CLASS__, 'wpf_search_products' ), 'wpf_product_options', 'normal' );
        }
		public static function wpf_search_products( $post ) {
            wp_nonce_field('wpf_options_rules_nonce', 'wpf_options_rules_nonce');
			$products = get_posts(array(
				'post_type' => array('product', 'product_variation'),
				'post_status' => 'publish',
				'fields' => 'ids',
				'meta_query' => array(
					array('key' => 'wpf_enable_product_options', 'value' => 'yes', 'compare' => '='),
					array('key' => 'wpf_select_option', 'value' => $post->ID, 'compare' => '=')
				)
			));
			$remove_prod_ids = !empty($products) ? implode(',', $products) : ''; ?>
            <div class="">
				<table class="form-table">
					<tr>
						<th><label for="wpf_options_products"><?php esc_html_e('Assign Options To Selected Products', 'wc-wpf'); ?></label></th>
						<td><select name="wpf_options_products[]" class="regular-text wc-product-search" multiple>
							<?php
							if ( !empty($products) ) {
								foreach ( $products as $product_id ) {
									echo '<option value = "' . esc_attr($product_id) . '" selected>' . esc_html__(get_the_title($product_id), 'wc-wpf') . '</option>';
								}
							} ?>
							</select>
							<input type="hidden" name="wpf_options_products_remove" value="<?php echo esc_attr($remove_prod_ids); ?>" />
						</td>
					</tr>
				</table>
			</div>
		<?php
		}
        public static function wpf_rule_fields_data( $post ) {
            wp_nonce_field('wpf_options_rules_nonce','wpf_options_rules_nonce'); ?>
            <div class="wpf_fields_section">
            <?php
            $options = get_post_meta($post->ID, 'wpf_product_option_rulset', true);
			$options = !empty($options) ? $options : array('');
            if ( !empty($options) ) {
                $i = 0;
                foreach ( $options as $key => $option ) {
                    $type = !empty($option['wpf_rule_type']) ? $option['wpf_rule_type'] : ''; ?>
                    <div class="wpf_rules_fields">
                        <div class="wpf_fields_header wc-metabox" data-option_type="<?php echo esc_attr($type); ?>">
                            <span class="wpf_option_title"><b><?php esc_html_e(str_replace('_', ' ', $type)); ?></b></span>
							<span class="dashicons dashicons-move wpf_move_option"></span>
							<span class="dashicons dashicons-trash wpf_remove"></span>
                        </div>
                        <div class="wpf_rule_fields">
                            <p class="wpf-form-field">
                                <label for="wpf_rule_type"><?php esc_html_e('Select Type: ','wc-wpf'); ?></label><br />
                                <select name="wpf_rule_type[]" class="regular-text wpf_rule_type">
                                    <option value=""><?php esc_html_e('Select type', 'wc-wpf'); ?></option>
                                    <option value="checkboxes" <?php selected('checkboxes', $type) ?>><?php esc_html_e('Checkboxes', 'wc-wpf'); ?></option>
                                    <option value="text_field" <?php selected('text_field', $type) ?>><?php esc_html_e('Text Field', 'wc-wpf'); ?></option>
                                    <option value="text_area" <?php selected('text_area', $type) ?>><?php esc_html_e('Text Area', 'wc-wpf'); ?></option>
                                    <option value="radio" <?php selected('radio', $type) ?>><?php esc_html_e('Radio', 'wc-wpf'); ?></option>
                                    <option value="dropdown" <?php selected('dropdown', $type) ?>><?php esc_html_e('Dropdown', 'wc-wpf'); ?></option>
                                    <option value="colorpicker" <?php selected('colorpicker', $type) ?>><?php esc_html_e('Color Picker', 'wc-wpf'); ?></option>
                                    <option value="time" <?php selected('time', $type) ?>><?php esc_html_e('Time', 'wc-wpf'); ?></option>
                                    <option value="date" <?php selected('date', $type) ?>><?php esc_html_e('Date', 'wc-wpf'); ?></option>
                                    <option value="multiselect" <?php selected('multiselect', $type) ?>><?php esc_html_e('Multi Select', 'wc-wpf'); ?></option>
                                    <option value="file" <?php selected('file', $type) ?>><?php esc_html_e('File', 'wc-wpf'); ?></option>
                                    <option value="price" <?php selected('price', $type) ?>><?php esc_html_e('Price', 'wc-wpf'); ?></option>
                                    <option value="quantity" <?php selected('quantity', $type) ?>><?php esc_html_e('Quantity', 'wc-wpf'); ?></option>
                                    <option value="heading" <?php selected('heading', $type) ?>><?php esc_html_e('Heading', 'wc-wpf'); ?></option>
                                    <option value="images" <?php selected('images', $type) ?>><?php esc_html_e('Images', 'wc-wpf'); ?></option>
                                    <option value="range_picker" <?php selected('range_picker', $type) ?>><?php esc_html_e('Range Picker', 'wc-wpf'); ?></option>
                                    <option value="date_range_picker" <?php selected('date_range_picker', $type) ?>><?php esc_html_e('Date Range Picker', 'wc-wpf'); ?></option>
									<option value="composite_products" <?php selected('composite_products', $type); ?>><?php esc_html_e('Composite Products', 'product-options'); ?></option>
									<option value="shortcode-html" <?php selected('shortcode-html', $type) ?>><?php esc_html_e('HTML/Shortcode', 'wc-wpf'); ?></option>
                                </select>
                            </p>
                            <p class="wpf-form-field">
                            <?php $label = !empty($option['wpf_option_label']) ? $option['wpf_option_label'] : ''; ?>
                                <label><?php esc_html_e('Label:', 'wc-wpf'); ?><br />
                                    <input type="text" class="wpf_option_label" name="wpf_option_label[]" value="<?php echo esc_attr($label); ?>" /></label>
                            </p>
							<p class="wpf-form-field wpf_html-shortcode">
								<?php $value = !empty($option['wpf_cutom_html']) ? $option['wpf_cutom_html'] : ''; ?>
								<?php //wp_editor( $value, 'wpf_cutom_html[]', array( 'textarea_rows' => 3, 'wpautop' => false ) ); ?><label><?php esc_html_e('Add Shortcode', 'wc-wpf'); ?></label><br />
								<textarea name="wpf_cutom_html[]"><?php echo $value; ?></textarea>
							</p>
                            <p class="wpf-form-field wpf_label_format">
                            <?php $format = !empty($option['wpf_label_format']) ? $option['wpf_label_format'] : ''; ?>
                                <label><?php esc_html_e('Format Label:', 'wc-wpf'); ?><br />
                                    <select name="wpf_label_format[]" class="regular-text">
                                        <option value="label" <?php selected('label', $format); ?>><?php esc_html_e('Label', 'wc-wpf'); ?></option>
                                        <option value="heading" <?php selected('heading', $format); ?>><?php esc_html_e('Heading', 'wc-wpf'); ?></option>
                                        <option value="disable" <?php selected('disable', $format); ?>><?php esc_html_e('Disable', 'wc-wpf'); ?></option>
                                    </select></label>
                            </p>
                            <p class="wpf-form-field">
                            <?php $desc = !empty($option['wpf_option_desc']) ? $option['wpf_option_desc'] : ''; ?>
                                <label><?php esc_html_e('Description:', 'wc-wpf'); ?><br />
                                    <textarea name="wpf_option_desc[]"><?php echo esc_html($desc); ?></textarea></label>
                            </p>
                            <p class="wpf-form-field wpf_option_required">
                            <?php $required = !empty($option['wpf_option_required']) ? $option['wpf_option_required'] : ''; ?>
                                <label><?php esc_html_e('Required?', 'wc-wpf'); ?>
                                    <input type="checkbox" class="wpf_option_required" name="wpf_option_required[<?php echo esc_attr($i); ?>]" value="yes" <?php checked('yes', $required); ?> />
                                </label>
                            </p>
                            <p class="wpf-form-field wpf_option_allow_multiple">
                            <?php $allow_multiple = !empty($option['wpf_option_allow_multiple']) ? $option['wpf_option_allow_multiple'] : ''; ?>
                                <label><?php esc_html_e('Allow Mulltiple?', 'wc-wpf'); ?>
                                    <input type="checkbox" class="wpf_option_allow_multiple" name="wpf_option_allow_multiple[<?php echo esc_attr($i); ?>]" value="yes" <?php checked('yes', $allow_multiple); ?> />
                                </label>
                            </p>
                            <p class="wpf-form-field wpf_option_text_pricing">
                            <?php $text_pricing = !empty($option['wpf_option_text_pricing']) ? $option['wpf_option_text_pricing'] : 'fixed'; ?>
                                <label><?php esc_html_e('Fixed Pricing:', 'wc-wpf'); ?>
                                    <input type="radio" class="wpf_option_text_pricing" name="wpf_option_text_pricing[<?php echo esc_attr($i); ?>]" value="fixed" <?php checked('fixed', $text_pricing); ?> />
                                </label>
                                <label><?php esc_html_e('Price Per Character:', 'wc-wpf'); ?>
                                    <input type="radio" class="wpf_option_text_pricing" name="wpf_option_text_pricing[<?php echo esc_attr($i); ?>]" value="per_char" <?php checked('per_char', $text_pricing); ?> />
                                </label>
                                <label><?php esc_html_e('Price Per Word:', 'wc-wpf'); ?>
                                    <input type="radio" class="wpf_option_text_pricing" name="wpf_option_text_pricing[<?php echo esc_attr($i); ?>]" value="per_word" <?php checked('per_word', $text_pricing); ?> />
                                </label>
                            </p>
                            <p class="wpf-form-field wpf_text_field_restriction">
                            <?php $text_rest = !empty($option['wpf_text_field_restriction']) ? $option['wpf_text_field_restriction'] : ''; ?>
                                <label><?php esc_html_e('Restriction:', 'wc-wpf'); ?><br />
                                    <select class="regular-text" name="wpf_text_field_restriction[]">
                                        <option value="any_text" <?php selected('any_text', $text_rest); ?>><?php esc_html_e('Any Text', 'wc-wpf'); ?></option>
                                        <option value="only_letter" <?php selected('only_letter', $text_rest); ?>><?php esc_html_e('Only Letters', 'wc-wpf'); ?></option>
                                        <option value="only_number" <?php selected('only_number', $text_rest); ?>><?php esc_html_e('Only Numbers', 'wc-wpf'); ?></option>
                                        <option value="letter_number" <?php selected('letter_number', $text_rest); ?>><?php esc_html_e('Letters and Numbers', 'wc-wpf'); ?></option>
                                        <option value="only_email" <?php selected('only_email', $text_rest); ?>><?php esc_html_e('Only Email', 'wc-wpf'); ?></option>
                                    </select>
                                </label>
                            </p>
                            <p class="wpf-form-field wpf_options_limit">
                            <?php $limit = !empty($option['wpf_options_limit']) ? $option['wpf_options_limit'] : ''; ?>
                                <label><?php esc_html_e('Charater Limit:', 'wc-wpf'); ?><br />
                                    <input type="number" class="regular-text" name="wpf_options_limit[]" value="<?php echo esc_attr($limit); ?>" /></label>
                            </p>
                            <p class="wpf-form-field wpf_option_price">
                            <?php $text_rest = !empty($option['wpf_option_pricing_type']) ? $option['wpf_option_pricing_type'] : ''; ?>
                                <label><?php esc_html_e('Pricing Type:', 'wc-wpf'); ?><br />
                                    <select class="regular-text" name="wpf_option_pricing_type[]">
                                        <option value="flate_fee" <?php selected('flate_fee', $text_rest); ?>><?php esc_html_e('Flate Fee', 'wc-wpf'); ?></option>
                                        <option value="percentage" <?php selected('percentage', $text_rest); ?>><?php esc_html_e('Percentage Based', 'wc-wpf'); ?></option>
                                    </select>
                                </label>
                            </p>
                            <p class="wpf-form-field wpf_option_price">
                                <?php $price = !empty($option['wpf_options_price']) ? $option['wpf_options_price'] : ''; ?>
                                <label><?php esc_html_e('Price:', 'wc-wpf'); ?><br />
                                    <input type="number" step="any" name="wpf_options_price[]" value="<?php echo esc_attr($price); ?>" />
                                </label>
                            </p>
                            <p class="wpf-form-field wpf_quantity_option">
                            <?php $min_qty = !empty($option['wpf_options_min_qty']) ? $option['wpf_options_min_qty'] : ''; ?>
                                <label><?php esc_html_e('Minimum Quantity:', 'wc-wpf'); ?><br />
                                    <input type="number" step="any" class="regular-text" name="wpf_options_min_qty[]" value="<?php echo esc_attr($min_qty); ?>" />
                                </label>
                            </p>
							<p class="wpf-form-field wpf_quantity_option">
                            <?php $step = !empty($option['wpf_options_step']) ? $option['wpf_options_step'] : ''; ?>
                                <label><?php esc_html_e('Step:', 'wc-wpf'); ?><br />
                                    <input type="number" step="any" class="regular-text" name="wpf_options_step[]" value="<?php echo esc_attr($step); ?>" />
                                </label>
                            </p>
                            <p class="wpf-form-field wpf_quantity_option">
                            <?php $max_qty = !empty($option['wpf_options_max_qty']) ? $option['wpf_options_max_qty'] : ''; ?>
                                <label><?php esc_html_e('Maximum Quantity:', 'wc-wpf'); ?><br />
                                    <input type="number" step="any" class="regular-text" name="wpf_options_max_qty[]" value="<?php echo esc_attr($max_qty); ?>" />
                                </label>
                            </p>
                            <p class="wpf-form-field wpf_price_option">
                            <?php $min_price = !empty($option['wpf_options_min_price']) ? $option['wpf_options_min_price'] : ''; ?>
                                <label><?php esc_html_e('Minimum Price:', 'wc-wpf'); ?><br />
                                    <input type="number" step="any" class="regular-text" name="wpf_options_min_price[]" value="<?php echo esc_attr($min_price); ?>" />
                                </label>
                            </p>
                            <p class="wpf-form-field wpf_price_option">
                            <?php $max_price = !empty($option['wpf_options_max_price']) ? $option['wpf_options_max_price'] : ''; ?>
                                <label><?php esc_html_e('Maximum Price:', 'wc-wpf'); ?><br />
                                    <input type="number" step="any" class="regular-text" name="wpf_options_max_price[]" value="<?php echo esc_attr($max_price); ?>" />
                                </label>
                            </p>
                            <div class="wpf_add_options">
                                <p><?php esc_html_e('Options:', 'wc-wpf'); ?></p>
                                <table>
                                    <tr>
                                        <th class="wpf_images"><?php esc_html_e('Images', 'wc-wpf'); ?></th>
                                        <th><?php esc_html_e('Option Label', 'wc-wpf'); ?></th>
                                        <th><?php esc_html_e('Price Type', 'wc-wpf'); ?></th>
                                        <th><?php esc_html_e('Price', 'wc-wpf'); ?></th>
                                        <th><?php esc_html_e('Action', 'wc-wpf'); ?></th>
                                    </tr>
                                    <?php
                                    $option_labels = !empty($option['wpf_multi_options_label']) ? $option['wpf_multi_options_label'] : array('');
                                    $j = 0;
                                    foreach ( $option_labels as $label ) { ?>
                                    <tr class="wpf_field_options">
                                        <td class="wpf_images">
                                            <a href="#" class="wpf_image_options">
                                            <?php $image_id = !empty($option['wpf_multi_options_image'][$j]) ? $option['wpf_multi_options_image'][$j] : '';
                                                if (!empty($image_id) && 'publish' == get_post_status($image_id) ) {
                                                    $image_src = wp_get_attachment_image_src($image_id);
                                                    $image_src = $image_src[0];
                                                } else {
                                                    $image_src = wc_placeholder_img_src();
                                                } ?>
                                                <img src="<?php echo esc_attr($image_src); ?>" width="35" height="35" />
                                                <input type="hidden" class="wpf_multi_options_image" name="wpf_multi_options_image[<?php echo esc_attr($i); ?>][]" value="<?php echo esc_attr($image_id); ?>" />
                                            </a>
                                        </td>
                                        <td><input type="text" class="wpf_multi_options_label" name="wpf_multi_options_label[<?php echo esc_attr($i); ?>][]" value="<?php echo esc_attr($label); ?>" /></td>
                                        <td>
                                        <?php $option_type = !empty($option['wpf_multi_options_price_type'][$j]) ? $option['wpf_multi_options_price_type'][$j] : ''; ?>
                                            <select class="wpf_multi_options_price_type" name="wpf_multi_options_price_type[<?php echo esc_attr($i); ?>][]">
                                                <option value="flate_fee" <?php selected('flate_fee', $option_type); ?>><?php esc_html_e('Flate Fee', 'wc-wpf'); ?></option>
                                                <option value="percentage" <?php selected('percentage', $option_type); ?>><?php esc_html_e('Percentage Based', 'wc-wpf'); ?></option>
                                            </select>
                                        </td>
                                        <?php $option_price = !empty($option['wpf_multi_options_price'][$j]) ? $option['wpf_multi_options_price'][$j] : ''; ?>
                                        <td><input class="wpf_multi_options_price" type="text" name="wpf_multi_options_price[<?php echo esc_attr($i); ?>][]" value="<?php echo esc_attr($option_price); ?>" /></td>
                                        <td><span class="dashicons dashicons-trash wpf_remove_options"></span></td>
                                    </tr>
                                    <?php $j++; } ?>
                                </table>
                                <button class="button wpf_add_field_options"><?php esc_html_e('Add Option', 'wc-wpf'); ?></button>
                            </div>
							<p class="pow-form-field wpf_option_products">
							<label><?php esc_html_e('Products:', 'wc-wpf'); ?><br />
							<?php $product_ids = !empty($option['wpf_option_products']) ? $option['wpf_option_products'] : array(); ?>
							<select name="wpf_option_products[<?php echo esc_attr($i); ?>][]" class="regular-text wc-product-search" multiple>
								<?php
								if ( !empty($product_ids) ) {
									foreach ( $product_ids as $product_id ) {
										echo '<option value = "' . esc_attr($product_id) . '" selected>' . esc_html__(get_the_title($product_id), 'product-options') . '</option>';
									}
								} 
								?>
								</select>
							</p>
                            <div class="wpf_conditional_logics">
                                <p><?php esc_html_e('Conditional Logics:', 'wc-wpf'); ?></p>
                                <div class="wpf_logic_box">
                                <?php
                                    $logic_status = !empty($option['wpf_logic_status']) ? $option['wpf_logic_status'] : '';
                                    $logic_option = !empty($option['wpf_logic_option']) ? $option['wpf_logic_option'] : '';
                                    $logic_select = !empty($option['wpf_logic_select']) ? $option['wpf_logic_select'] : '';
                                    $logic_value = !empty($option['wpf_logic_value']) ? $option['wpf_logic_value'] : ''; ?>
                                    <div class="wpf_logic">
                                        <select class="wpf_logic_status" name="wpf_logic_status[]">
                                            <option value=""><?php esc_html_e('Select', 'wc-wpf'); ?></option>
                                            <option value="show" <?php selected('show', $logic_status); ?>><?php esc_html_e('Show', 'wc-wpf'); ?></option>
                                            <option value="hide" <?php selected('hide', $logic_status); ?>><?php esc_html_e('Hide', 'wc-wpf'); ?></option>
                                        </select>
                                        <label><?php esc_html_e('If value of ', 'wp-wpf'); ?><select class="wpf_logic_option" name="wpf_logic_option[]">
                                        <?php if ( !empty($options) ) {
                                            foreach ( $options as $k => $optn ) {
												$labl = !empty($optn['wpf_option_label']) ? $optn['wpf_option_label'] : '';
                                                echo '<option value="' . esc_attr($k) . '" ' . selected($k, $logic_option, false) . '>' . esc_html($labl) . '</option>';
                                            }
                                        } ?>
                                        </select>
                                        <select class="wpf_logic_select" name="wpf_logic_select[]">
                                            <option value=""><?php esc_html_e('Select', 'wc-wpf'); ?></option>
                                            <option value="is_equal" <?php selected('is_equal', $logic_select); ?>><?php esc_html_e('Is equal to', 'wc-wpf'); ?></option>
                                            <option value="not_equal" <?php selected('not_equal', $logic_select); ?>><?php esc_html_e('Not equal to', 'wc-wpf'); ?></option>
                                            <option value="greater" <?php selected('greater', $logic_select); ?>><?php esc_html_e('Greater than', 'wc-wpf'); ?></option>
                                            <option value="less" <?php selected('less', $logic_select); ?>><?php esc_html_e('Less than', 'wc-wpf'); ?></option>
                                            <option value="greater_equal" <?php selected('greater_equal', $logic_select); ?>><?php esc_html_e('Greater than or equal to', 'wc-wpf'); ?></option>
                                            <option value="less_equal" <?php selected('less_equal', $logic_select); ?>><?php esc_html_e('Less than or equal to', 'wc-wpf'); ?></option>
                                            <option value="is_empty" <?php selected('is_empty', $logic_select); ?>><?php esc_html_e('is empty', 'wc-wpf'); ?></option>
                                            <option value="not_empty" <?php selected('not_empty', $logic_select); ?>><?php esc_html_e('not empty', 'wc-wpf'); ?></option>
                                        </select>
                                        <input type="text" class="wpf_logic_value" name="wpf_logic_value[]" value="<?php echo esc_attr($logic_value); ?>" />
                                        <p><?php esc_html_e('Select option again if any option dragged and dropped.', 'wc-wpf') ?></p>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php $i++; }
                } ?>
                <div>
                    <button class="wpf_add_option button-primary"><?php esc_html_e('Add New Option', 'wc-wpf'); ?></button>
                </div>
            </div>
            <?php
        }
        public static function wpf_save_rules( $post_id ) {
            if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
                return;
            }
            if ( !current_user_can('edit_post', $post_id) ) {
                return;
            }
			if ( !empty($_POST['wpf_options_products_remove']) ) {
				$remove_product_ids = explode(',', wc_clean($_POST['wpf_options_products_remove']));
				foreach ($remove_product_ids as $product_id ) {
					update_post_meta($product_id, 'wpf_select_option', '');
					update_post_meta($product_id, 'wpf_enable_product_options', '');
				}
			}
			if ( !empty($_POST['wpf_options_products']) ) {
				$product_ids = wc_clean($_POST['wpf_options_products']);
				foreach ($product_ids as $product_id ) {
					update_post_meta($product_id, 'wpf_select_option', wc_clean($post_id));
					update_post_meta($product_id, 'wpf_enable_product_options', 'yes');
				}
			}
            if ( isset( $_POST['wpf_options_rules_nonce'] ) ) {
                if ( wp_verify_nonce( $_POST['wpf_options_rules_nonce'], 'wpf_options_rules_nonce') ) {
                    $options = array();
                    for ( $i = 0; $i < count($_POST['wpf_rule_type']); $i++ ) {
                        $options[$i]['wpf_rule_type'] = !empty($_POST['wpf_rule_type'][$i]) ? wc_clean($_POST['wpf_rule_type'][$i]) : '';
                        $options[$i]['wpf_option_label'] = !empty($_POST['wpf_option_label'][$i]) ? wc_clean($_POST['wpf_option_label'][$i]) : '';
                        $options[$i]['wpf_label_format'] = !empty($_POST['wpf_label_format'][$i]) ? wc_clean($_POST['wpf_label_format'][$i]) : '';
						$options[$i]['wpf_cutom_html'] = !empty($_POST['wpf_cutom_html'][$i]) ? wc_clean($_POST['wpf_cutom_html'][$i]) : '';
                        $options[$i]['wpf_option_required'] = !empty($_POST['wpf_option_required'][$i]) ? wc_clean($_POST['wpf_option_required'][$i]) : '';
                        $options[$i]['wpf_option_allow_multiple'] = !empty($_POST['wpf_option_allow_multiple'][$i]) ? wc_clean($_POST['wpf_option_allow_multiple'][$i]) : '';
                        $options[$i]['wpf_option_text_pricing'] = !empty($_POST['wpf_option_text_pricing'][$i]) ? wc_clean($_POST['wpf_option_text_pricing'][$i]) : '';
                        $options[$i]['wpf_text_field_restriction'] = !empty($_POST['wpf_text_field_restriction'][$i]) ? wc_clean($_POST['wpf_text_field_restriction'][$i]) : '';
                        $options[$i]['wpf_options_limit'] = !empty($_POST['wpf_options_limit'][$i]) ? wc_clean($_POST['wpf_options_limit'][$i]) : '';
                        $options[$i]['wpf_option_pricing_type'] = !empty($_POST['wpf_option_pricing_type'][$i]) ? wc_clean($_POST['wpf_option_pricing_type'][$i]) : '';
                        $options[$i]['wpf_options_price'] = !empty($_POST['wpf_options_price'][$i]) ? wc_clean($_POST['wpf_options_price'][$i]) : '';
                        $options[$i]['wpf_options_min_qty'] = !empty($_POST['wpf_options_min_qty'][$i]) ? wc_clean($_POST['wpf_options_min_qty'][$i]) : '';
						$options[$i]['wpf_options_step'] = !empty($_POST['wpf_options_step'][$i]) ? wc_clean($_POST['wpf_options_step'][$i]) : '';
                        $options[$i]['wpf_options_max_qty'] = !empty($_POST['wpf_options_max_qty'][$i]) ? wc_clean($_POST['wpf_options_max_qty'][$i]) : '';
                        $options[$i]['wpf_options_min_price'] = !empty($_POST['wpf_options_min_price'][$i]) ? wc_clean($_POST['wpf_options_min_price'][$i]) : '';
                        $options[$i]['wpf_options_max_price'] = !empty($_POST['wpf_options_max_price'][$i]) ? wc_clean($_POST['wpf_options_max_price'][$i]) : '';
                        $options[$i]['wpf_option_desc'] = !empty($_POST['wpf_option_desc'][$i]) ? wc_clean($_POST['wpf_option_desc'][$i]) : '';
						$options[$i]['wpf_option_products'] = !empty($_POST['wpf_option_products'][$i]) ? array_unique(wc_clean($_POST['wpf_option_products'][$i])) : array('');
                        $options[$i]['wpf_multi_options_image'] = !empty($_POST['wpf_multi_options_image'][$i]) ? wc_clean($_POST['wpf_multi_options_image'][$i]) : '';
                        $options[$i]['wpf_multi_options_label'] = !empty($_POST['wpf_multi_options_label'][$i]) ? wc_clean($_POST['wpf_multi_options_label'][$i]) : array('');
                        $options[$i]['wpf_multi_options_price_type'] = !empty($_POST['wpf_multi_options_price_type'][$i]) ? wc_clean($_POST['wpf_multi_options_price_type'][$i]) : array('');
                        $options[$i]['wpf_multi_options_price'] = !empty($_POST['wpf_multi_options_price'][$i]) ? wc_clean($_POST['wpf_multi_options_price'][$i]) : array('');
                        $options[$i]['wpf_logic_status'] = !empty($_POST['wpf_logic_status'][$i]) ? wc_clean($_POST['wpf_logic_status'][$i]) : '';
                        $options[$i]['wpf_logic_select'] = !empty($_POST['wpf_logic_select'][$i]) ? wc_clean($_POST['wpf_logic_select'][$i]) : '';
                        $options[$i]['wpf_logic_value'] = !empty($_POST['wpf_logic_value'][$i]) ? wc_clean($_POST['wpf_logic_value'][$i]) : '';
                        $options[$i]['wpf_logic_option'] = wc_clean($_POST['wpf_logic_option'][$i]);
                    }
                    update_post_meta($post_id, 'wpf_product_option_rulset', wc_clean($options));
                }
            }
        }
 	}
 	new WPF_Product_Option_Rules();
}