<?php
/*
* Plugin Name: WooCommerce Product Options
* Description: The plugin for WooCommerce Product Options.
* Plugin URI: https://www.persianscript.ir
* Version: 1.0.9
* Author: پرشین اسکریپت
* Author URI: https://www.persianscript.ir
* Support: http://www.wpmajesty.com/
* License: GPL-2.0+
* License URI: http://www.gnu.org/licenses/gpl-2.0.txt
* Text Domain: wc-wpf
* Domain Path: /languages/
*/
if ( !defined( 'ABSPATH' ) ) {
	wp_die();
}
if ( !defined( 'WP_WPF_URL' ) ) {
	define( 'WP_WPF_URL' , plugin_dir_url( __FILE__ ) );
}
if ( !defined('WP_WPF_DIR') ) {
	define( 'WP_WPF_DIR' , plugin_dir_path( __FILE__ ) );
}
if ( !class_exists( 'WPF_Product_Options' ) ) {
	class WPF_Product_Options{
		public function __construct() {
			if ( ! function_exists( 'is_plugin_active_for_network' ) ) {
				require_once( ABSPATH . '/wp-admin/includes/plugin.php' );
			}
			if ( in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins'))) || is_plugin_active_for_network( 'woocommerce/woocommerce.php' ) ) {
				self::wpf_init_plugin_files();
			} else {
				add_action( 'admin_notices', array( __CLASS__, 'wpf_admin_notice') );
			}
			add_action( 'before_woocommerce_init', array( __CLASS__, 'wpf_woocommerce_hpos_compatible' ) );
		}
		public static function wpf_woocommerce_hpos_compatible() {
			if ( class_exists( '\Automattic\WooCommerce\Utilities\FeaturesUtil' ) ) {
				\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
			}
		}
		public static function wpf_init_plugin_files() {
			if ( function_exists( 'load_plugin_textdomain' ) ) {
				load_plugin_textdomain( 'wc-wpf', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
			}
			require_once WP_WPF_DIR . 'include/functions.php';
			require_once WP_WPF_DIR . 'include/class-common.php';
			if ( is_admin() ) {
				require_once WP_WPF_DIR . 'include/admin.php';
			} else {
				require_once WP_WPF_DIR . 'include/frontend.php';
			}
		}
		public static function wpf_admin_notice() {
			global $pagenow;
	        if ( 'plugins.php' === $pagenow ) {
	            $class = esc_attr( 'notice notice-error is-dismissible' );
	            $message = esc_html__('WooCommerce Product Options plugin needs WooCommerce to be installed and active.', 'wc-wpf');
	            printf('<div class="%1$s"><p>%2$s</p></div>', $class, $message);
		    }
		}
	}
	new WPF_Product_Options();
}